document.addEventListener('DOMContentLoaded', () => {
  // Sample property data
  const properties = [
    {
      id: 1,
      image: 'data:image/jpeg;base64,/9j/4AAQSkZJRg==',
      price: 450000,
      address: '123 Main St, Anytown, USA',
      beds: 3,
      baths: 2,
      sqft: 2000,
      type: 'house'
    },
    // Add more properties here
  ];

  const listingsContainer = document.getElementById('listings');
  const searchBtn = document.getElementById('searchBtn');
  const searchInput = document.getElementById('search');
  const propertyTypeSelect = document.getElementById('propertyType');
  const priceRangeSelect = document.getElementById('priceRange');
  const bedsSelect = document.getElementById('beds');

  function createPropertyCard(property) {
    return `
      <div class="property-card">
        <img src="${property.image}" alt="Property" class="property-image">
        <div class="property-info">
          <div class="property-price">$${property.price.toLocaleString()}</div>
          <p>${property.address}</p>
          <p>${property.beds} beds | ${property.baths} baths | ${property.sqft} sqft</p>
        </div>
      </div>
    `;
  }

  function filterProperties() {
    const searchTerm = searchInput.value.toLowerCase();
    const propertyType = propertyTypeSelect.value;
    const priceRange = priceRangeSelect.value;
    const minBeds = parseInt(bedsSelect.value) || 0;

    const filtered = properties.filter(property => {
      const matchesSearch = property.address.toLowerCase().includes(searchTerm);
      const matchesType = !propertyType || property.type === propertyType;
      const matchesBeds = property.beds >= minBeds;
      
      let matchesPrice = true;
      if (priceRange) {
        const [min, max] = priceRange.split('-').map(Number);
        matchesPrice = property.price >= min && (!max || property.price <= max);
      }

      return matchesSearch && matchesType && matchesBeds && matchesPrice;
    });

    listingsContainer.innerHTML = filtered.map(createPropertyCard).join('');
  }

  // Event listeners
  searchBtn.addEventListener('click', filterProperties);
  searchInput.addEventListener('keyup', event => {
    if (event.key === 'Enter') filterProperties();
  });
  propertyTypeSelect.addEventListener('change', filterProperties);
  priceRangeSelect.addEventListener('change', filterProperties);
  bedsSelect.addEventListener('change', filterProperties);

  // Initial load
  filterProperties();
});
